@@ -461,7 +461,7 @@ def distribution_parameters(distribution):
     max_value = distribution.max()
     min_value = distribution.min()
     median_value = np.median(distribution)
-    mean_value = np.median(distribution)
+    mean_value = np.mean(distribution)
     modes, _ = stats.mode(distribution)
     mode = modes[0]
     std = np.std(distribution)
